netapp_ontap.models.qos_policy_adaptive API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.qos_policy_adaptive`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class QosPolicyAdaptiveSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the QosPolicyAdaptive object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `absolute_min_iops: Size GET POST PATCH`

    Specifies the absolute minimum IOPS that is used as an override when the expected_iops is less than this value. These floors are not guaranteed on non-AFF platforms or when FabricPool tiering policies are set.

  `block_size: str GET POST PATCH`

    Specifies the block size

    Valid choices:

    - any
    - 4k
    - 8k
    - 16k
    - 32k
    - 64k
    - 128k
  `expected_iops: Size GET POST PATCH`

    Expected IOPS. Specifies the minimum expected IOPS per TB allocated based on the storage object allocated size. These floors are not guaranteed on non-AFF platforms or when FabricPool tiering policies are set.

  `expected_iops_allocation: str GET POST PATCH`

    Specifies the size to be used to calculate expected IOPS per TB. The size options are either the storage object allocated space or the storage object used space.

    Valid choices:

    - used_space
    - allocated_space
  `peak_iops: Size GET POST PATCH`

    Peak IOPS. Specifies the maximum possible IOPS per TB allocated based on the storage object allocated size or the storage object used size.

  `peak_iops_allocation: str GET POST PATCH`

    Specifies the size to be used to calculate peak IOPS per TB. The size options are either the storage object allocated space or the storage object used space.

    Valid choices:

    - used_space
    - allocated_space